@@ -13,12 +13,7 @@ import pytest
 def run_pytest(*args):
     """ Run pytest and return its exit status. """
 
-    pytest_args = [
-        '--doctest-modules',
-        '--doctest-ignore-import-errors',
-        '--ignore=setup.py',
-    ] + list(args)
-    errno = pytest.main(pytest_args)
+    errno = pytest.main(args)
 
     return errno
 
